package liv.cache.ahead;

import org.apache.commons.pool.KeyedPoolableObjectFactory;

/**
 * Factory class which delegates all the methods to {@link CacheableAhead} for
 * creating instances of classes.
 *
 * @author Liviu Tudor http://about.me/liviutudor
 * @param <V>
 *            Type of class it operates on.
 */
public class CreateInstanceFactory<V extends CacheableAhead> implements KeyedPoolableObjectFactory<Class<V>, V> {
    @Override
    public V makeObject(Class<V> key) throws InstantiationException, IllegalAccessException {
        return key.newInstance();
    }

    @Override
    public void destroyObject(Class<V> key, V obj) throws Exception {
        obj.destroy();
    }

    @Override
    public boolean validateObject(Class<V> key, V obj) {
        return obj.isValid();
    }

    @Override
    public void activateObject(Class<V> key, V obj) throws Exception {
        obj.activate();
    }

    @Override
    public void passivateObject(Class<V> key, V obj) throws Exception {
        obj.passivate();
    }
}
