package liv.cache.ahead;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * Dummy cacheable ahead implementation used in unit tests in this package.
 * Simply counts the number of calls and allows to configure the results of
 * {@link #isValid()}.
 *
 * @author Liviu Tudor http://about.me/liviutudor
 */
public class DummyCacheableAhead implements CacheableAhead {
    private int     activateCalls;
    private int     passivateCalls;
    private int     destroyCalls;
    private int     isValidCalls;
    /**
     * Set at construct time. Decides the returned value of {@link #isValid()}.
     */
    private boolean valid;

    public DummyCacheableAhead() {
        this(true);
    }

    public DummyCacheableAhead(boolean valid) {
        this.valid = valid;
        activateCalls = passivateCalls = destroyCalls = isValidCalls = 0;
    }

    @Override
    public void activate() {
        activateCalls++;
    }

    @Override
    public void passivate() {
        passivateCalls++;
    }

    @Override
    public void destroy() {
        destroyCalls++;
    }

    @Override
    public boolean isValid() {
        isValidCalls++;
        return valid;
    }

    public void setValid(boolean valid) {
        this.valid = valid;
    }

    public final int getActivateCalls() {
        return activateCalls;
    }

    public final int getPassivateCalls() {
        return passivateCalls;
    }

    public final int getDestroyCalls() {
        return destroyCalls;
    }

    public final int getIsValidCalls() {
        return isValidCalls;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
